@@ -58,6 +58,12 @@ sub TIEHANDLE {
 sub READLINE {
   my $self = shift;
 
+  if (wantarray) {
+    my @data = ();
+    while (defined(my $line = $self->READLINE())) { push @data, $line }
+    return @data
+  }
+
   return undef if $self->[AT_EOF];
 
   my $line = readline $self->[HANDLE];
